==> connector-runtime-spring-8.5.12-sources.jar: io/camunda/connector/runtime/inbound/importer/ProcessDefinitionImportConfiguration.java <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH
 * under one or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information regarding copyright
 * ownership. Camunda licenses this file to you under the Apache License,
 * Version 2.0; you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.camunda.connector.runtime.inbound.importer;

import io.camunda.connector.runtime.inbound.lifecycle.InboundConnectorManager;
import io.camunda.operate.CamundaOperateClient;
import io.camunda.zeebe.spring.client.metrics.MetricsRecorder;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
public class ProcessDefinitionImportConfiguration {

  @Bean
  public ProcessDefinitionSearch processDefinitionSearch(CamundaOperateClient client) {
    return new ProcessDefinitionSearch(client);
  }

  @Bean
  public ProcessDefinitionImporter processDefinitionImporter(
      InboundConnectorManager manager,
      ProcessDefinitionSearch search,
      MetricsRecorder metricsRecorder) {
    return new ProcessDefinitionImporter(manager, search, metricsRecorder);
  }

  @Bean
  public ProcessDefinitionInspector processDefinitionInspector(CamundaOperateClient client) {
    return new ProcessDefinitionInspector(client);
  }
}

==> connector-runtime-spring-8.6.6-sources.jar: io/camunda/connector/runtime/inbound/importer/ProcessDefinitionImportConfiguration.java <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH
 * under one or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information regarding copyright
 * ownership. Camunda licenses this file to you under the Apache License,
 * Version 2.0; you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.camunda.connector.runtime.inbound.importer;

import io.camunda.connector.runtime.inbound.state.ProcessStateStore;
import io.camunda.operate.CamundaOperateClient;
import io.camunda.zeebe.spring.client.metrics.MetricsRecorder;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
public class ProcessDefinitionImportConfiguration {

  @Bean
  public ProcessDefinitionSearch processDefinitionSearch(CamundaOperateClient client) {
    return new ProcessDefinitionSearch(client);
  }

  @Bean
  public ProcessDefinitionImporter processDefinitionImporter(
      ProcessStateStore stateStore,
      ProcessDefinitionSearch search,
      MetricsRecorder metricsRecorder) {
    return new ProcessDefinitionImporter(stateStore, search, metricsRecorder);
  }
}
